import { defineStore } from 'pinia';
import REST from '../api/rest-axios';

export const useContentStore = defineStore('content', {
  state: () => ({
      href: '',
      etape: {
        title: '',
        adresse: {},
        etape_number: '',
        dates: {},
        geofield: {},
        galeries: [],
        parties: [],
        saison: {},
        thematiques: [],
        vignette: {},
      },
      page: {
        title: '', 
        text: '',
      },
      loading: false,
      error: null,
    }),
    actions: {
      async fetchEtapeData(nid) {
        this.loading = true;
        this.error = null;
        this.etape = {};
        this.page = {};
        try {
          const response = await REST.get(`/jsonapi/node/etape/`);
          for (let etape of response.data.data) {
            if (etape.attributes.drupal_internal__nid == nid) {
              for (let metatag of etape.attributes.metatag) {
                if (metatag.tag === "link") {
                  this.href = metatag.attributes.href;
                }
              }
              this.etape.title = etape.attributes.title;
              this.etape.adresse = etape.attributes.field_adresse;
              this.etape.etape_number = etape.attributes.field_arret_numero;
              this.etape.dates = etape.attributes.field_dates;
              this.etape.geofield = etape.attributes.field_geofield;
              this.etape.galeries = await this.fetchEtapeContent('field_galleries', etape.relationships);
              const partiesFetch = await this.fetchEtapeContent('field_parties', etape.relationships);
              let partiesArray = []
              for (let partie of partiesFetch) {
                partiesArray.push({ title: partie.attributes.field_titre, text: partie.attributes.field_texte.value });
              }
              this.etape.parties = partiesArray;
              this.etape.saison = await this.fetchEtapeContent('field_saison', etape.relationships);
              this.etape.saison = await this.fetchEtapeContent('field_saison', etape.relationships);
              this.etape.thematiques = await this.fetchEtapeContent('field_thematiques', etape.relationships);
              const vignetteFetch = await this.fetchEtapeContent('field_vignette', etape.relationships);
              this.etape.vignette = { url: vignetteFetch.attributes.uri.url, alt: etape.attributes.field_vignette_alt };
              this.setActiveItemInMenu();
              break;
            }
          }
        } catch (error) {
          this.error = 'Failed to fetch data';
          console.error('Issue with getNodeData', error);
        } finally {
          this.loading = false;
        }
      },
      async fetchStaticData(nid) {
        this.loading = true;
        this.error = null;
        this.etape = {};
        this.page = {};
        try {
          const response = await REST.get(`/jsonapi/node/static/`);
          for (let staticContent of response.data.data) {
            if (staticContent.attributes.drupal_internal__nid == nid) {
              staticContent.attributes.metatag.forEach(item => {
                if (item.tag === 'meta') {
                  this.page.title = item.attributes.content.split(' |')[0];
                }
                if (item.tag === 'link') {
                  this.href = item.attributes.href;
                }
              })
              this.page.text = staticContent.attributes.field_texte.value;
            }
          }
          this.setActiveItemInMenu();
        } catch (error) {
          this.error = 'Failed to fetch data';
          console.error('Issue with getNodeData', error);
        } finally {
          this.loading = false;
        }
      },
      emptyAll() {
        this.etape = {};
        this.page = {};
        this.setActiveItemInMenu();
      },
      setActiveItemInMenu() {
        const title = this.etape.title || this.page.title;

        const generalLinks = document.querySelectorAll('#menu > ul > li > a');
        if (Object.entries(this.etape).length === 0 && Object.entries(this.page).length === 0) {
          for (let link of generalLinks) {
            link.classList.remove('is-active');
          }
          generalLinks[0].classList.add('is-active');
        } else {
          for (let link of generalLinks) {
            if (link.innerText === title) {
              link.classList.add('is-active');
            } else {
              link.classList.remove('is-active');
            }
          }
        }

        const etapeLinks = document.querySelectorAll('#etapes-liste li');
        for (let link of etapeLinks) {
          const a = link.querySelector('a');
          if (a.innerText === title) {
            link.classList.remove('inactive');
          } else {
            link.classList.add('inactive');
          }
        }
        const inactiveLinks = document.querySelectorAll('#etapes-liste li.inactive');
        if (inactiveLinks.length === etapeLinks.length) {
          for (let link of inactiveLinks) {
            link.classList.remove('inactive');
          }
        }
      },
      async fetchEtapeContent(field, relationships) {
        if (relationships[field].data) {
          try {
            const contentLink = relationships[field].links.related.href;
            const contentFetch = await REST.get(contentLink);
            return contentFetch.data.data;
          } catch (error) {
            this.error = 'Failed to fetch data';
            console.error('Issue with getNodeData', error);
          }
        }
      }
    },
  });

